#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hakyll
version:              4.16.4.0
visibility:           public
id:                   hakyll-4.16.4.0-LEWpR4lGhtM49W8rjTvLXK
key:                  hakyll-4.16.4.0-LEWpR4lGhtM49W8rjTvLXK
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on irc.libera.chat (we *do not* have a channel on Freenode anymore)

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  32ac6536b93db67aab14414e22f547c7
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Meta.JSONLD
    Hakyll.Web.Meta.OpenGraph Hakyll.Web.Meta.TwitterCard
    Hakyll.Web.Paginate Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.16.4.0-LEWpR4lGhtM49W8rjTvLXK
depends:
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW base-4.18.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-BrSAzNVQiYJEXfJmmg87r5 bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    deepseq-1.4.8.1 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    fsnotify-0.4.4.0-Km92ObfvjbA6uSaVR1a7w9
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    http-conduit-2.3.9.1-1jgAUVyqkxJ6z3Pvba5xG2
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    lrucache-1.2.0.1-34e4rU2OpGtGXjnvLtyFkI mtl-2.3.1
    network-uri-2.6.4.2-1K7fB5RWUkvJzcj2EjtnE4
    optparse-applicative-0.18.1.0-3oCCN3996F8HtRiEC4P5yD
    pandoc-3.6-1DKE0x92VRa5b3GF6kWKcy parsec-3.1.16.1 process-1.6.19.0
    random-1.2.1.3-Gsn6cRa5LQY7Fg5vZFQhOU
    regex-tdfa-1.3.2.5-6zmUIdhGbUZEJaVpWcqCOZ
    resourcet-1.2.6-GrVaNPG3RF7IMcvlKlmJk8
    scientific-0.3.8.1-38VvnYA00bD5k7zFFQre1V
    tagsoup-0.14.8-EUJgnzyeT340o0wxyvxVK template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc
    wai-3.2.4-4nidytGQQ7OHwip6f8eKmG
    wai-app-static-3.1.9-5bCgDdmkAgbAkpKRSBQarx
    warp-3.4.0-EuoVZnUEXzN8epINQKmpB7
    yaml-0.11.11.2-4phsW6UFS0g9E55EDT6q72

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

